@@ -120,6 +120,11 @@ setValues <- function(x, value) {
     return(x)
 }
 
+setDates <- function(x, value) {
+    x[] <- mapply(setDate, x[], value = value, SIMPLIFY = FALSE)
+    return(x)
+}
+
 #' @rdname describe-catalog
 #' @export
 setMethod("values", "Categories", function(x) vapply(x, value, numeric(1)))
@@ -128,6 +133,16 @@ setMethod("values", "Categories", function(x) vapply(x, value, numeric(1)))
 #' @export
 setMethod("values<-", "Categories", setValues)
 
+#' @rdname describe-catalog
+#' @export
+setMethod("dates", "Categories", function(x) {
+    structure(vapply(x, dates, character(1), USE.NAMES = FALSE), .Names = names(x))
+})
+
+#' @rdname describe-catalog
+#' @export
+setMethod("dates<-", "Categories", setDates)
+
 #' @rdname is-na-categories
 #' @aliases is-na-categories
 #' @export
