@@ -1,18 +1,18 @@
 #' @rdname tuple-methods
 #' @export
-setMethod("$", "ShojiEntity", function (x, name) x@body[[name]])
+setMethod("$", "ShojiEntity", function(x, name) x@body[[name]])
 #' @rdname tuple-methods
 #' @export
-setMethod("$<-", "ShojiEntity", function (x, name, value) {
+setMethod("$<-", "ShojiEntity", function(x, name, value) {
     x[[name]] <- value
     return(x)
 })
 #' @rdname tuple-methods
 #' @export
-setMethod("[[", "ShojiEntity", function (x, i) x@body[[i]])
+setMethod("[[", "ShojiEntity", function(x, i) x@body[[i]])
 #' @rdname tuple-methods
 #' @export
-setMethod("[[<-", "ShojiEntity", function (x, i, value) {
+setMethod("[[<-", "ShojiEntity", function(x, i, value) {
     if (is.variable(value)) {
         ## Setting a weight: get its URL
         ## Generalize this `if` whenever needed
@@ -24,7 +24,7 @@ setMethod("[[<-", "ShojiEntity", function (x, i, value) {
     return(x)
 })
 
-updateEntity <- function (x, value) {
+updateEntity <- function(x, value) {
     old <- x@body
     new <- value@body
 
@@ -32,13 +32,15 @@ updateEntity <- function (x, value) {
     newattrs <- setdiff(names(new), names(old))
     if (length(newattrs)) {
         halt("Invalid attribute", ifelse(length(newattrs) > 1, "s: ", ": "),
-            serialPaste(newattrs), call.=FALSE)
+            serialPaste(newattrs),
+            call. = FALSE
+        )
     }
     ## Now look for updates
     common <- intersect(names(new), names(old))
     changed <- dirtyElements(old[common], new[common])
     if (any(changed)) {
-        crPATCH(self(x), body=toJSON(new[common[changed]]))
+        crPATCH(self(x), body = toJSON(new[common[changed]]))
         x <- refresh(x)
     }
     return(x)
