@@ -471,16 +471,6 @@ with_test_authentication({
         )
     })
 
-    test_that("Another test for text truncation", {
-        source("mapcty.R")
-        ds <- newDataset(data.frame(x = seq_along(mapcty)))
-        ds$county <- factor(mapcty)
-        expect_identical(
-            as.character(head(as.vector(ds$county))),
-            head(mapcty)
-        )
-    })
-
     ds <- newDataset(df)
     test_that("Categorical to R and back", {
         v4 <- as.vector(ds$v4)
