@@ -4,7 +4,8 @@ context("UTF-8 Encoding")
 test_that("All test- files are ASCII (for CHECK)", {
     testfiles <- dir(pattern = "^test.*R$")
     for (i in testfiles) {
-        expect_warning(scan(i, what = character(), fileEncoding = "ascii", quiet = TRUE),
+        expect_warning(
+            scan(i, what = character(), fileEncoding = "ascii", quiet = TRUE),
             NA,
             info = i
         )
