@@ -1,7 +1,7 @@
 context("Variables")
 
 with_mock_crunch({
-    ds <- loadDataset("test ds")
+    ds <- cachedLoadDataset("test ds")
     ds2 <- loadDataset("an archived dataset", "archived")
 
     test_that("Variable init, as, is", {
